
# Slot: source


a lightweight analog to the association class 'has provider' slot, which is the string name, or the authoritative (i.e. database) namespace, designating the origin of the entity to which the slot belongs.

URI: [biolink:source](https://w3id.org/biolink/vocab/source)


## Domain and Range

None &#8594;  <sub>0..1</sub> [LabelType](types/LabelType.md)

## Parents


## Children


## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [Activity](Activity.md)
 * [AdministrativeEntity](AdministrativeEntity.md)
 * [Agent](Agent.md)
 * [AnatomicalEntity](AnatomicalEntity.md)
 * [AnatomicalEntityToAnatomicalEntityAssociation](AnatomicalEntityToAnatomicalEntityAssociation.md)
 * [AnatomicalEntityToAnatomicalEntityOntogenicAssociation](AnatomicalEntityToAnatomicalEntityOntogenicAssociation.md)
 * [AnatomicalEntityToAnatomicalEntityPartOfAssociation](AnatomicalEntityToAnatomicalEntityPartOfAssociation.md)
 * [Article](Article.md)
 * [Association](Association.md)
 * [Attribute](Attribute.md)
 * [Behavior](Behavior.md)
 * [BehaviorToBehavioralFeatureAssociation](BehaviorToBehavioralFeatureAssociation.md)
 * [BehavioralExposure](BehavioralExposure.md)
 * [BehavioralFeature](BehavioralFeature.md)
 * [BehavioralOutcome](BehavioralOutcome.md)
 * [BiologicalEntity](BiologicalEntity.md)
 * [BiologicalProcess](BiologicalProcess.md)
 * [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)
 * [BiologicalSex](BiologicalSex.md)
 * [BioticExposure](BioticExposure.md)
 * [Book](Book.md)
 * [BookChapter](BookChapter.md)
 * [Carbohydrate](Carbohydrate.md)
 * [Case](Case.md)
 * [CaseToPhenotypicFeatureAssociation](CaseToPhenotypicFeatureAssociation.md)
 * [Cell](Cell.md)
 * [CellLine](CellLine.md)
 * [CellLineAsAModelOfDiseaseAssociation](CellLineAsAModelOfDiseaseAssociation.md)
 * [CellLineToDiseaseOrPhenotypicFeatureAssociation](CellLineToDiseaseOrPhenotypicFeatureAssociation.md)
 * [CellularComponent](CellularComponent.md)
 * [ChemicalExposure](ChemicalExposure.md)
 * [ChemicalSubstance](ChemicalSubstance.md)
 * [ChemicalToChemicalAssociation](ChemicalToChemicalAssociation.md)
 * [ChemicalToChemicalDerivationAssociation](ChemicalToChemicalDerivationAssociation.md)
 * [ChemicalToDiseaseOrPhenotypicFeatureAssociation](ChemicalToDiseaseOrPhenotypicFeatureAssociation.md)
 * [ChemicalToGeneAssociation](ChemicalToGeneAssociation.md)
 * [ChemicalToPathwayAssociation](ChemicalToPathwayAssociation.md)
 * [ClinicalAttribute](ClinicalAttribute.md)
 * [ClinicalCourse](ClinicalCourse.md)
 * [ClinicalEntity](ClinicalEntity.md)
 * [ClinicalFinding](ClinicalFinding.md)
 * [ClinicalIntervention](ClinicalIntervention.md)
 * [ClinicalMeasurement](ClinicalMeasurement.md)
 * [ClinicalModifier](ClinicalModifier.md)
 * [ClinicalTrial](ClinicalTrial.md)
 * [CodingSequence](CodingSequence.md)
 * [Cohort](Cohort.md)
 * [ComplexChemicalExposure](ComplexChemicalExposure.md)
 * [ConfidenceLevel](ConfidenceLevel.md)
 * [ContributorAssociation](ContributorAssociation.md)
 * [Dataset](Dataset.md)
 * [DatasetDistribution](DatasetDistribution.md)
 * [DatasetSummary](DatasetSummary.md)
 * [DatasetVersion](DatasetVersion.md)
 * [Death](Death.md)
 * [Device](Device.md)
 * [Disease](Disease.md)
 * [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)
 * [DiseaseOrPhenotypicFeatureAssociationToLocationAssociation](DiseaseOrPhenotypicFeatureAssociationToLocationAssociation.md)
 * [DiseaseOrPhenotypicFeatureExposure](DiseaseOrPhenotypicFeatureExposure.md)
 * [DiseaseOrPhenotypicFeatureOutcome](DiseaseOrPhenotypicFeatureOutcome.md)
 * [DiseaseOrPhenotypicFeatureToLocationAssociation](DiseaseOrPhenotypicFeatureToLocationAssociation.md)
 * [DiseaseToExposureEventAssociation](DiseaseToExposureEventAssociation.md)
 * [DiseaseToPhenotypicFeatureAssociation](DiseaseToPhenotypicFeatureAssociation.md)
 * [Drug](Drug.md)
 * [DrugExposure](DrugExposure.md)
 * [DrugToGeneAssociation](DrugToGeneAssociation.md)
 * [DrugToGeneInteractionExposure](DrugToGeneInteractionExposure.md)
 * [Entity](Entity.md)
 * [EnvironmentalExposure](EnvironmentalExposure.md)
 * [EnvironmentalFeature](EnvironmentalFeature.md)
 * [EnvironmentalFoodContaminant](EnvironmentalFoodContaminant.md)
 * [EnvironmentalProcess](EnvironmentalProcess.md)
 * [EpidemiologicalOutcome](EpidemiologicalOutcome.md)
 * [EvidenceType](EvidenceType.md)
 * [Exon](Exon.md)
 * [ExonToTranscriptRelationship](ExonToTranscriptRelationship.md)
 * [ExposureEventToOutcomeAssociation](ExposureEventToOutcomeAssociation.md)
 * [ExposureEventToPhenotypicFeatureAssociation](ExposureEventToPhenotypicFeatureAssociation.md)
 * [Food](Food.md)
 * [FoodAdditive](FoodAdditive.md)
 * [FoodComponent](FoodComponent.md)
 * [FunctionalAssociation](FunctionalAssociation.md)
 * [Gene](Gene.md)
 * [GeneAsAModelOfDiseaseAssociation](GeneAsAModelOfDiseaseAssociation.md)
 * [GeneFamily](GeneFamily.md)
 * [GeneHasVariantThatContributesToDiseaseAssociation](GeneHasVariantThatContributesToDiseaseAssociation.md)
 * [GeneRegulatoryRelationship](GeneRegulatoryRelationship.md)
 * [GeneToDiseaseAssociation](GeneToDiseaseAssociation.md)
 * [GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md)
 * [GeneToGeneAssociation](GeneToGeneAssociation.md)
 * [GeneToGeneCoexpressionAssociation](GeneToGeneCoexpressionAssociation.md)
 * [GeneToGeneHomologyAssociation](GeneToGeneHomologyAssociation.md)
 * [GeneToGeneProductRelationship](GeneToGeneProductRelationship.md)
 * [GeneToGoTermAssociation](GeneToGoTermAssociation.md)
 * [GeneToPhenotypicFeatureAssociation](GeneToPhenotypicFeatureAssociation.md)
 * [Genome](Genome.md)
 * [GenomicBackgroundExposure](GenomicBackgroundExposure.md)
 * [GenomicEntity](GenomicEntity.md)
 * [GenomicSequenceLocalization](GenomicSequenceLocalization.md)
 * [Genotype](Genotype.md)
 * [GenotypeAsAModelOfDiseaseAssociation](GenotypeAsAModelOfDiseaseAssociation.md)
 * [GenotypeToDiseaseAssociation](GenotypeToDiseaseAssociation.md)
 * [GenotypeToGeneAssociation](GenotypeToGeneAssociation.md)
 * [GenotypeToGenotypePartAssociation](GenotypeToGenotypePartAssociation.md)
 * [GenotypeToPhenotypicFeatureAssociation](GenotypeToPhenotypicFeatureAssociation.md)
 * [GenotypeToVariantAssociation](GenotypeToVariantAssociation.md)
 * [GenotypicSex](GenotypicSex.md)
 * [GeographicExposure](GeographicExposure.md)
 * [GeographicLocation](GeographicLocation.md)
 * [GeographicLocationAtTime](GeographicLocationAtTime.md)
 * [GrossAnatomicalStructure](GrossAnatomicalStructure.md)
 * [Haplotype](Haplotype.md)
 * [Hospitalization](Hospitalization.md)
 * [HospitalizationOutcome](HospitalizationOutcome.md)
 * [IndividualOrganism](IndividualOrganism.md)
 * [InformationContentEntity](InformationContentEntity.md)
 * [Inheritance](Inheritance.md)
 * [LifeStage](LifeStage.md)
 * [MacromolecularMachineToBiologicalProcessAssociation](MacromolecularMachineToBiologicalProcessAssociation.md)
 * [MacromolecularMachineToCellularComponentAssociation](MacromolecularMachineToCellularComponentAssociation.md)
 * [MacromolecularMachineToMolecularActivityAssociation](MacromolecularMachineToMolecularActivityAssociation.md)
 * [Macronutrient](Macronutrient.md)
 * [MaterialSample](MaterialSample.md)
 * [MaterialSampleDerivationAssociation](MaterialSampleDerivationAssociation.md)
 * [MaterialSampleToDiseaseOrPhenotypicFeatureAssociation](MaterialSampleToDiseaseOrPhenotypicFeatureAssociation.md)
 * [Metabolite](Metabolite.md)
 * [MicroRNA](MicroRNA.md)
 * [Micronutrient](Micronutrient.md)
 * [MolecularActivity](MolecularActivity.md)
 * [MolecularEntity](MolecularEntity.md)
 * [MortalityOutcome](MortalityOutcome.md)
 * [NamedThing](NamedThing.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [Nutrient](Nutrient.md)
 * [Onset](Onset.md)
 * [OrganismAttribute](OrganismAttribute.md)
 * [OrganismTaxon](OrganismTaxon.md)
 * [OrganismTaxonToEnvironmentAssociation](OrganismTaxonToEnvironmentAssociation.md)
 * [OrganismTaxonToOrganismTaxonAssociation](OrganismTaxonToOrganismTaxonAssociation.md)
 * [OrganismTaxonToOrganismTaxonInteraction](OrganismTaxonToOrganismTaxonInteraction.md)
 * [OrganismTaxonToOrganismTaxonSpecialization](OrganismTaxonToOrganismTaxonSpecialization.md)
 * [OrganismalEntity](OrganismalEntity.md)
 * [OrganismalEntityAsAModelOfDiseaseAssociation](OrganismalEntityAsAModelOfDiseaseAssociation.md)
 * [PairwiseGeneToGeneInteraction](PairwiseGeneToGeneInteraction.md)
 * [PairwiseMolecularInteraction](PairwiseMolecularInteraction.md)
 * [PathologicalAnatomicalExposure](PathologicalAnatomicalExposure.md)
 * [PathologicalAnatomicalOutcome](PathologicalAnatomicalOutcome.md)
 * [PathologicalAnatomicalStructure](PathologicalAnatomicalStructure.md)
 * [PathologicalProcess](PathologicalProcess.md)
 * [PathologicalProcessExposure](PathologicalProcessExposure.md)
 * [PathologicalProcessOutcome](PathologicalProcessOutcome.md)
 * [Pathway](Pathway.md)
 * [Phenomenon](Phenomenon.md)
 * [PhenotypicFeature](PhenotypicFeature.md)
 * [PhenotypicQuality](PhenotypicQuality.md)
 * [PhenotypicSex](PhenotypicSex.md)
 * [PhysicalEntity](PhysicalEntity.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)
 * [PlanetaryEntity](PlanetaryEntity.md)
 * [PopulationOfIndividualOrganisms](PopulationOfIndividualOrganisms.md)
 * [PopulationToPopulationAssociation](PopulationToPopulationAssociation.md)
 * [Procedure](Procedure.md)
 * [ProcessedMaterial](ProcessedMaterial.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)
 * [Publication](Publication.md)
 * [ReagentTargetedGene](ReagentTargetedGene.md)
 * [SequenceAssociation](SequenceAssociation.md)
 * [SequenceFeatureRelationship](SequenceFeatureRelationship.md)
 * [SequenceVariant](SequenceVariant.md)
 * [SequenceVariantModulatesTreatmentAssociation](SequenceVariantModulatesTreatmentAssociation.md)
 * [Serial](Serial.md)
 * [SeverityValue](SeverityValue.md)
 * [SiRNA](SiRNA.md)
 * [Snv](Snv.md)
 * [SocioeconomicAttribute](SocioeconomicAttribute.md)
 * [SocioeconomicExposure](SocioeconomicExposure.md)
 * [SocioeconomicOutcome](SocioeconomicOutcome.md)
 * [StudyPopulation](StudyPopulation.md)
 * [Transcript](Transcript.md)
 * [TranscriptToGeneRelationship](TranscriptToGeneRelationship.md)
 * [Treatment](Treatment.md)
 * [VariantAsAModelOfDiseaseAssociation](VariantAsAModelOfDiseaseAssociation.md)
 * [VariantToDiseaseAssociation](VariantToDiseaseAssociation.md)
 * [VariantToGeneAssociation](VariantToGeneAssociation.md)
 * [VariantToGeneExpressionAssociation](VariantToGeneExpressionAssociation.md)
 * [VariantToPhenotypicFeatureAssociation](VariantToPhenotypicFeatureAssociation.md)
 * [VariantToPopulationAssociation](VariantToPopulationAssociation.md)
 * [Vitamin](Vitamin.md)
 * [Zygosity](Zygosity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |

